==> mrzflutterplugin-0.1.1.tar.gz: android/src/main/kotlin/com/scansolutions/mrzflutterplugin/ScannerActivity.java <==
package com.scansolutions.mrzflutterplugin;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.view.Window;
import android.view.WindowManager;

import com.scansolutions.mrzscannerlib.MRZResultModel;
import com.scansolutions.mrzscannerlib.MRZScanner;
import com.scansolutions.mrzscannerlib.MRZScannerListener;
import com.scansolutions.mrzscannerlib.ScannerType;

import androidx.appcompat.app.AppCompatActivity;

public class ScannerActivity extends AppCompatActivity implements MRZScannerListener {

    static int scannerType = 0;
    static MRZScannerListener mrzScannerListener;
    //    static final String OVERLAY_IMG_KEY = "MRZ_BITMAP_PATH";
//    static final String OVERLAY_IMG_NAME = "MRZ_OVERLAY_IMG.jpg";
    private MRZScanner mrzScanner;
    static MRZScannerDismissedListener mrzScannerDismissed;
//    private static Activity activityInstance;

    public static void startScanner(Context context, MRZScannerListener listener, /*String base64String,*/ MRZScannerDismissedListener mrzScannerDismissedListener) {
        mrzScannerListener = listener;
        mrzScannerDismissed = mrzScannerDismissedListener;
        Intent intent = new Intent(context, ScannerActivity.class);

//        if (base64String != null && !"".equals(base64String)) {
//            String imagePath = ScannerActivity.saveToInternalStorage(base64String, context);
//            intent.putExtra(ScannerActivity.OVERLAY_IMG_KEY, imagePath);
//        }

        context.startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.requestWindowFeature(Window.FEATURE_NO_TITLE);
        this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContentView(R.layout.activity_scanner);
//        activityInstance = this;
//        String imagePathId = getIntent().getStringExtra(OVERLAY_IMG_KEY);
//        Bitmap overlayImage = loadImageFromStorage(imagePathId);

        mrzScanner = (MRZScanner) getSupportFragmentManager().findFragmentById(R.id.scannerFragment);
        mrzScanner.setScannerType(ScannerType.values()[scannerType]);
//        mrzScanner.setCustomImageOverlay(overlayImage);
    }

    @Override
    public void successfulScanWithResult(MRZResultModel mrzResultModel) {
        mrzScannerListener.successfulScanWithResult(mrzResultModel);
        finish();
    }

    @Override
    public void successfulScanWithDocumentImage(Bitmap bitmap) {
        mrzScannerListener.successfulScanWithDocumentImage(bitmap);
        finish();
    }

    @Override
    public void scanImageFailed() {
        mrzScannerListener.scanImageFailed();
        finish();
    }

    @Override
    public void permissionsWereDenied() {
        mrzScannerListener.permissionsWereDenied();
        finish();
    }

    void resumeScanning() {
        mrzScanner.resumeScanning();
    }

    //
//    private static Bitmap loadImageFromStorage(String path) {
//        Bitmap b = null;
//        try {
//            File f = new File(path, OVERLAY_IMG_NAME);
//            b = BitmapFactory.decodeStream(new FileInputStream(f));
//        } catch (FileNotFoundException e) {
//            e.printStackTrace();
//        }
//        return b;
//    }
//
    @Override
    public void onBackPressed() {
        super.onBackPressed();
        if (mrzScannerDismissed != null)
            mrzScannerDismissed.scannerWasDismissed();
    }

//    private static String saveToInternalStorage(String base64String, Context context) {
//        Bitmap bitmap = RNMrzscannerlibModule.decodeBase64(base64String);
//
//        File directory = context.getDir("imageDir", Context.MODE_PRIVATE);
//        // Create imageDir
//        File mypath = new File(directory, ScannerActivity.OVERLAY_IMG_NAME);
//
//        FileOutputStream fos = null;
//        try {
//            fos = new FileOutputStream(mypath);
//            // Use the compress method on the BitMap object to write image to the OutputStream
//            bitmap.compress(Bitmap.CompressFormat.PNG, 100, fos);
//        } catch (Exception e) {
//            e.printStackTrace();
//        } finally {
//            try {
//                fos.close();
//            } catch (IOException e) {
//                e.printStackTrace();
//            }
//        }
//        return directory.getAbsolutePath();
//    }
//    static void finishActivity(){
//        if (activityInstance != null){
//            activityInstance.onBackPressed();
//        }
//    }
//
//    @Override
//    protected void onDestroy() {
//        super.onDestroy();
//        activityInstance = null;
//    }

    static void setIdActive(Boolean active) {
        MRZScanner.setIDActive(active);
    }

    static void setPassportActive(Boolean active) {
        MRZScanner.setIDActive(active);
    }

    static void setVisaActive(Boolean active) {
        MRZScanner.setIDActive(active);
    }
}

==> mrzflutterplugin-0.1.3.tar.gz: android/src/main/kotlin/com/scansolutions/mrzflutterplugin/ScannerActivity.java <==
package com.scansolutions.mrzflutterplugin;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.view.Window;
import android.view.WindowManager;

import com.scansolutions.mrzscannerlib.MRZResultModel;
import com.scansolutions.mrzscannerlib.MRZScanner;
import com.scansolutions.mrzscannerlib.MRZScannerListener;
import com.scansolutions.mrzscannerlib.ScannerType;

import androidx.appcompat.app.AppCompatActivity;

public class ScannerActivity extends AppCompatActivity implements MRZScannerListener {

    static int sScannerType = 0;
    static MRZScannerListener mrzScannerListener;
    //    static final String OVERLAY_IMG_KEY = "MRZ_BITMAP_PATH";
//    static final String OVERLAY_IMG_NAME = "MRZ_OVERLAY_IMG.jpg";
    private MRZScanner mrzScanner;
    static MRZScannerDismissedListener mrzScannerDismissed;
//    private static Activity activityInstance;

    public static void startScanner(Context context, int scannerType, MRZScannerListener listener, /*String base64String,*/ MRZScannerDismissedListener mrzScannerDismissedListener) {
        sScannerType = scannerType;
        mrzScannerListener = listener;
        mrzScannerDismissed = mrzScannerDismissedListener;
        Intent intent = new Intent(context, ScannerActivity.class);

//        if (base64String != null && !"".equals(base64String)) {
//            String imagePath = ScannerActivity.saveToInternalStorage(base64String, context);
//            intent.putExtra(ScannerActivity.OVERLAY_IMG_KEY, imagePath);
//        }

        context.startActivity(intent);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.requestWindowFeature(Window.FEATURE_NO_TITLE);
        this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
        setContentView(R.layout.activity_scanner);
//        activityInstance = this;
//        String imagePathId = getIntent().getStringExtra(OVERLAY_IMG_KEY);
//        Bitmap overlayImage = loadImageFromStorage(imagePathId);

        mrzScanner = (MRZScanner) getSupportFragmentManager().findFragmentById(R.id.scannerFragment);
        mrzScanner.setScannerType(ScannerType.values()[sScannerType]);
//        mrzScanner.setCustomImageOverlay(overlayImage);
    }

    @Override
    public void successfulScanWithResult(MRZResultModel mrzResultModel) {
        mrzScannerListener.successfulScanWithResult(mrzResultModel);
        finish();
    }

    @Override
    public void successfulScanWithDocumentImage(Bitmap bitmap) {
        mrzScannerListener.successfulScanWithDocumentImage(bitmap);
        finish();
    }

    @Override
    public void scanImageFailed() {
        mrzScannerListener.scanImageFailed();
        finish();
    }

    @Override
    public void permissionsWereDenied() {
        mrzScannerListener.permissionsWereDenied();
        finish();
    }

    void resumeScanning() {
        mrzScanner.resumeScanning();
    }

    //
//    private static Bitmap loadImageFromStorage(String path) {
//        Bitmap b = null;
//        try {
//            File f = new File(path, OVERLAY_IMG_NAME);
//            b = BitmapFactory.decodeStream(new FileInputStream(f));
//        } catch (FileNotFoundException e) {
//            e.printStackTrace();
//        }
//        return b;
//    }
//
    @Override
    public void onBackPressed() {
        super.onBackPressed();
        if (mrzScannerDismissed != null)
            mrzScannerDismissed.scannerWasDismissed();
    }

//    private static String saveToInternalStorage(String base64String, Context context) {
//        Bitmap bitmap = RNMrzscannerlibModule.decodeBase64(base64String);
//
//        File directory = context.getDir("imageDir", Context.MODE_PRIVATE);
//        // Create imageDir
//        File mypath = new File(directory, ScannerActivity.OVERLAY_IMG_NAME);
//
//        FileOutputStream fos = null;
//        try {
//            fos = new FileOutputStream(mypath);
//            // Use the compress method on the BitMap object to write image to the OutputStream
//            bitmap.compress(Bitmap.CompressFormat.PNG, 100, fos);
//        } catch (Exception e) {
//            e.printStackTrace();
//        } finally {
//            try {
//                fos.close();
//            } catch (IOException e) {
//                e.printStackTrace();
//            }
//        }
//        return directory.getAbsolutePath();
//    }
//    static void finishActivity(){
//        if (activityInstance != null){
//            activityInstance.onBackPressed();
//        }
//    }
//
//    @Override
//    protected void onDestroy() {
//        super.onDestroy();
//        activityInstance = null;
//    }

    static void setIdActive(Boolean active) {
        MRZScanner.setIDActive(active);
    }

    static void setPassportActive(Boolean active) {
        MRZScanner.setIDActive(active);
    }

    static void setVisaActive(Boolean active) {
        MRZScanner.setIDActive(active);
    }
}
